module ApplicationHelper
  def syntax_highlight(content, language = 'text', options = {})
    return '' if content.blank?
    
    css_classes = ["language-#{language}"]
    css_classes << 'line-numbers' if options[:line_numbers]
    
    content_tag :pre, class: css_classes.join(' ') do
      content_tag :code, content, class: "language-#{language}"
    end
  end

  def language_icon(language)
    icons = {
      'javascript' => '🟨',
      'python' => '🐍',
      'ruby' => '💎',
      'java' => '☕',
      'php' => '🐘',
      'html' => '🌐',
      'css' => '🎨',
      'sql' => '🗄️',
      'json' => '📋',
      'xml' => '📄',
      'bash' => '🐚',
      'go' => '🐹',
      'rust' => '🦀',
      'typescript' => '🔷'
    }
    
    icons[language.to_s.downcase] || '📄'
  end

  def time_ago_in_words_short(time)
    return '' unless time
    
    distance = Time.current - time
    
    case distance
    when 0..59
      "#{distance.to_i}s ago"
    when 60..3599
      "#{(distance / 60).to_i}m ago"
    when 3600..86399
      "#{(distance / 3600).to_i}h ago"
    when 86400..2591999
      "#{(distance / 86400).to_i}d ago"
    else
      time.strftime('%b %d, %Y')
    end
  end

  def truncate_content(content, length = 150)
    return '' if content.blank?
    
    if content.length > length
      content[0..length].gsub(/\s\w+\s*$/, '...')
    else
      content
    end
  end
end
